@@ -7,7 +7,9 @@ set -e
 cd "`dirname \"$0\"`"
 cd "../../.."
 
-python3 setup.py sdist
+rm -rf dist
+pip3 install build
+python3 -m build
 archive=`echo dist/icalendar-*.tar.gz`
 
 if ! [ -f "$archive" ]; then
@@ -15,10 +17,16 @@ if ! [ -f "$archive" ]; then
   exit 1
 fi
 
-if tar -tf "$archive" | grep 'fuzzing/'; then
+if tar -tf "$archive" | grep -q 'fuzzing/'; then
   echo "ERROR: Fuzzing files are included in the release."
   echo "       See https://github.com/collective/icalendar/pull/569"
   exit 1
 fi
 
+if ! tar -tf "$archive" | grep -q '/docs/'; then
+  echo "ERROR: The documentation is not included in the release, but should be."
+  echo "       See https://github.com/collective/icalendar/issues/712"
+  exit 1
+fi
+
 echo "Checks passed."
